import { createVNode as _createVNode } from "vue";
import { defineComponent } from "vue";
import { isDef, truthProp, makeArrayProp, makeStringProp, createNamespace } from "../utils/index.mjs";
import { Cell } from "../cell/index.mjs";
const [name, bem, t] = createNamespace("coupon-cell");
const couponCellProps = {
  title: String,
  border: truthProp,
  editable: truthProp,
  coupons: makeArrayProp(),
  currency: makeStringProp("\xA5"),
  chosenCoupon: {
    type: [Number, Array],
    default: -1
  }
};
function formatValue({
  coupons,
  chosenCoupon,
  currency
}) {
  const getValue = (coupon) => {
    let value2 = 0;
    const {
      value: couponValue,
      denominations
    } = coupon;
    if (isDef(coupon.value)) {
      value2 = couponValue;
    } else if (isDef(coupon.denominations)) {
      value2 = denominations;
    }
    return value2;
  };
  let value = 0, isExist = false;
  if (Array.isArray(chosenCoupon)) {
    chosenCoupon.forEach((i) => {
      const coupon = coupons[+i];
      if (coupon) {
        isExist = true;
        value += getValue(coupon);
      }
    });
  } else {
    const coupon = coupons[+chosenCoupon];
    if (coupon) {
      isExist = true;
      value = getValue(coupon);
    }
  }
  if (!isExist) {
    return coupons.length === 0 ? t("noCoupon") : t("count", coupons.length);
  }
  return `-${currency} ${(value / 100).toFixed(2)}`;
}
var stdin_default = defineComponent({
  name,
  props: couponCellProps,
  setup(props) {
    return () => {
      const selected = Array.isArray(props.chosenCoupon) ? props.chosenCoupon.length : props.coupons[+props.chosenCoupon];
      return _createVNode(Cell, {
        "class": bem(),
        "value": formatValue(props),
        "title": props.title || t("title"),
        "border": props.border,
        "isLink": props.editable,
        "valueClass": bem("value", {
          selected
        })
      }, null);
    };
  }
});
export {
  couponCellProps,
  stdin_default as default
};
